@@ -8,16 +8,17 @@ App::CLI::Extension::Component::Config - for App::CLI::Extension config module
 
 =head1 VERSION
 
-1.3
+1.4
 
 =cut
 
 use strict;
-use base qw(Class::Data::Accessor);
+use base qw(Class::Accessor::Grouped);
 
-our $VERSION  = '1.3';
+our $VERSION  = '1.4';
 
-__PACKAGE__->mk_classaccessor( _config => {} );
+__PACKAGE__->mk_group_accessors( "inherited" => "_config" );
+__PACKAGE__->_config({});
 
 sub config {
 
@@ -42,7 +43,7 @@ __END__
 
 =head1 SEE ALSO
 
-L<App::CLI::Extension> L<Class::Data::Accessor>
+L<App::CLI::Extension> L<Class::Accessor::Grouped>
 
 =head1 AUTHOR
 
