@@ -8,20 +8,21 @@ App::CLI::Extension::Component::OriginalArgv - for App::CLI::Extension original
 
 =head1 VERSION
 
-1.3
+1.4
 
 =cut
 
 use strict;
-use base qw(Class::Data::Accessor);
+use base qw(Class::Accessor::Grouped);
 use FindBin qw($Bin $Script);
 use File::Spec;
 
-our $VERSION  = '1.3';
+our $VERSION  = '1.4';
+
+__PACKAGE__->mk_group_accessors(inherited => "_orig_argv", "argv0", "full_argv0");
+__PACKAGE__->argv0($Script);
+__PACKAGE__->full_argv0(File::Spec->catfile($Bin, $Script));
 
-__PACKAGE__->mk_classaccessor("_orig_argv");
-__PACKAGE__->mk_classaccessor("argv0"      => $Script);
-__PACKAGE__->mk_classaccessor("full_argv0" => File::Spec->catfile($Bin, $Script));
 
 sub orig_argv {
 
@@ -54,7 +55,7 @@ __END__
 
 =head1 SEE ALSO
 
-L<App::CLI::Extension> L<Class::Data::Accessor>
+L<App::CLI::Extension> L<Class::Accessor::Grouped>
 
 =head1 AUTHOR
 
